use std::net::SocketAddr;

use clap::{Parser, Subcommand};

#[derive(Parser)]
#[command(author, version, about, long_about = None, subcommand_required = true)]
struct Command {
    #[command(subcommand)]
    command: Option<Commands>,
}

#[derive(Subcommand)]
enum Commands {
    Bootstrap {
        #[arg(env = "CHURN_AGENT", long)]
        agent: String,

        #[arg(env = "CHURN_SERVER", long)]
        server: String,

        #[arg(env = "CHURN_SERVER_TOKEN", long)]
        server_token: String,
    },
    Health {
        #[arg(env = "CHURN_SERVER", long)]
        server: String,
        #[arg(env = "CHURN_AGENT", long)]
        agent: String,
    },
}

#[tokio::main]
async fn main() -> anyhow::Result<()> {
    dotenv::dotenv().ok();
    tracing_subscriber::fmt::init();

    let cli = Command::parse();

    handle_command(cli).await?;

    Ok(())
}

async fn handle_command(cmd: Command) -> anyhow::Result<()> {
    if let Some(cmd) = cmd.command {
        match cmd {
            Commands::Bootstrap {
                agent,
                server,
                server_token,
            } => todo!(),
            Commands::Health { server, agent } => {
                tracing::info!("connecting to server: {}", server);
                reqwest::get(format!("{server}/ping")).await?;
                tracing::info!("connected to server successfully");
                tracing::info!("connecting to agent: {}", agent);
                reqwest::get(format!("{agent}/ping")).await?;
                tracing::info!("connected to agent successfully");
                Ok(())
            }
        }
    } else {
        panic!("no command supplied")
    }
}
